@@ -1,5 +1,4 @@
 <?php
-// $Id: panels_renderer_standard.class.php,v 1.1.2.32 2011/01/12 23:48:44 merlinofchaos Exp $
 
 /**
  * The standard render pipeline for a Panels display object.
@@ -537,13 +536,20 @@ class panels_renderer_standard {
       $content = $cache->content;
     }
     else {
+      if ($caching) {
+        $cache = new panels_cache_object();
+      }
       $content = ctools_content_render($pane->type, $pane->subtype, $pane->configuration, array(), $this->display->args, $this->display->context);
+      if (empty($content)) {
+        return;
+      }
+
       foreach (module_implements('panels_pane_content_alter') as $module) {
         $function = $module . '_panels_pane_content_alter';
         $function($content, $pane, $this->display->args, $this->display->context);
       }
-      if ($caching) {
-        $cache = new panels_cache_object();
+
+      if ($caching && isset($cache)) {
         $cache->set_content($content);
         panels_set_cached_content($cache, $this->display, $this->display->args, $this->display->context, $pane);
         $content = $cache->content;
